Module simulation
fakecloud_
eventbridge
0.8.1
Module simulation
Module Items
Structs
Functions
In crate fakecloud_
eventbridge
fakecloud_eventbridge
Module
simulation
Structs

Fired
Target
Result of firing a rule via simulation.
Functions

fire_
rule
Fire a specific rule by bus name and rule name, delivering to all its targets regardless of the rule’s enabled/disabled state.